==> otp_verification-8.x-1.0.tar.gz: otp_verification/src/MiniorangeOtpCustomer.php <==
<?php
/**
 * @file
 * Contains miniOrange Customer class.
 */
namespace Drupal\otp_verification;
/**
 * @file
 * This class represents configuration for customer.
 */
class MiniorangeOtpCustomer {

  public $email;
  public $phone;
  public $customerKey;
  public $transactionId;
  public $password;
  public $otpToken;
  public $defaultCustomerId;
  public $defaultCustomerApiKey;

  public static $pcode = "ZHJ1cGFsX290cF92ZXJpZmljYXRpb25fYmFzaWNfcGxhbg==";              //drupal_otp_verification_basic_plan
  public static $bcode = "ZHJ1cGFsX290cF92ZXJpZmljYXRpb25fcHJlbWl1bV9wbGFu";              //drupal_otp_verification_premium_plan

  /**
   * Constructor.
   */
  public function __construct($email, $phone, $password, $otp_token) {
    $this->email = $email;
    $this->phone = $phone;
    $this->password = $password;
    $this->otpToken = $otp_token;
    $this->defaultCustomerId = '16555';
    $this->defaultCustomerApiKey = 'fFd2XcvTGDemZvbw1bcUesNJWEqKbbUq';
  }


  /**
   * Value empty or null.
   */
  public static function moCheckEmptyOrNull($value) {
    if (!isset($value) || empty($value)) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Check customer license.
   */
  public function checkCustomerLn() {

    $url = 'https://login.xecurify.com/moas/rest/customer/license';
    $ch = curl_init($url);

    /* The customer Key provided to you */
    $customer_key = \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_id');

    /* The customer API Key provided to you */
    $api_key = \Drupal::config('otp_verification.settings')->get('miniorange_otp_verification_customer_api_key');
    /* Current time in milliseconds since midnight, January 1, 1970 UTC. */
    $current_time_in_millis = round(microtime(TRUE) * 1000);

    /* Creating the Hash using SHA-512 algorithm */
    $string_to_hash = $customer_key . number_format($current_time_in_millis, 0, '', '') . $api_key;
    $hash_value = hash("sha512", $string_to_hash);

    $customer_key_header = "Customer-Key: " . $customer_key;
    $timestamp_header = "Timestamp: " . $current_time_in_millis;
    $authorization_header = "Authorization: " . $hash_value;
    $fields = '';

    // Check for otp over sms/email.
    $fields = array(
      'customerId' => $customer_key,
      'applicationName' => 'drupal_otp',
    );
    $field_string = json_encode($fields);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
    curl_setopt($ch, CURLOPT_ENCODING, "");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
    // Required for https urls.
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);

    curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: application/json",
      $customer_key_header, $timestamp_header, $authorization_header,
    ));
    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
    curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
    curl_setopt($ch, CURLOPT_TIMEOUT, 20);
    $content = curl_exec($ch);

    if (curl_errno($ch)) {
      return NULL;
    }
    curl_close($ch);
    return $content;
  }

}

==> otp_verification-8.x-1.1.tar.gz: otp_verification/src/MiniorangeOtpCustomer.php <==
<?php
/**
 * @file
 * Contains miniOrange Customer class.
 */
namespace Drupal\otp_verification;
/**
 * @file
 * This class represents configuration for customer.
 */
class MiniorangeOtpCustomer {

  public $email;
  public $phone;
  public $customerKey;
  public $transactionId;
  public $password;
  public $otpToken;
  public $defaultCustomerId;
  public $defaultCustomerApiKey;

  public static $pcode = "ZHJ1cGFsX290cF92ZXJpZmljYXRpb25fYmFzaWNfcGxhbg==";              //drupal_otp_verification_basic_plan
  public static $bcode = "ZHJ1cGFsX290cF92ZXJpZmljYXRpb25fcHJlbWl1bV9wbGFu";              //drupal_otp_verification_premium_plan

  /**
   * Constructor.
   */
  public function __construct($email, $phone, $password, $otp_token) {
    $this->email = $email;
    $this->phone = $phone;
    $this->password = $password;
    $this->otpToken = $otp_token;
    $this->defaultCustomerId = '16555';
    $this->defaultCustomerApiKey = 'fFd2XcvTGDemZvbw1bcUesNJWEqKbbUq';
  }


  /**
   * Value empty or null.
   */
  public static function moCheckEmptyOrNull($value) {
    if (!isset($value) || empty($value)) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Check customer license.
   */
  public function checkCustomerLn() {

    $config = \Drupal::config('otp_verification.settings');

    $url = 'https://login.xecurify.com/moas/rest/customer/license';
    $ch = curl_init($url);

    /* The customer Key provided to you */
    $customer_key = $config->get('miniorange_otp_verification_customer_id');

    /* The customer API Key provided to you */
    $api_key = $config->get('miniorange_otp_verification_customer_api_key');
    /* Current time in milliseconds since midnight, January 1, 1970 UTC. */
    $current_time_in_millis = round(microtime(TRUE) * 1000);

    /* Creating the Hash using SHA-512 algorithm */
    $string_to_hash = $customer_key . number_format($current_time_in_millis, 0, '', '') . $api_key;
    $hash_value = hash("sha512", $string_to_hash);

    $customer_key_header = "Customer-Key: " . $customer_key;
    $timestamp_header = "Timestamp: " . $current_time_in_millis;
    $authorization_header = "Authorization: " . $hash_value;
    $fields = '';

    // Check for otp over sms/email.
    $fields = array(
      'customerId' => $customer_key,
      'applicationName' => 'drupal_otp',
    );
    $field_string = json_encode($fields);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
    curl_setopt($ch, CURLOPT_ENCODING, "");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
    // Required for https urls.
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);

    curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: application/json",
      $customer_key_header, $timestamp_header, $authorization_header,
    ));
    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
    curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
    curl_setopt($ch, CURLOPT_TIMEOUT, 20);
    $content = curl_exec($ch);

    if (curl_errno($ch)) {
      return NULL;
    }
    curl_close($ch);
    return $content;
  }

}
